# Warning: this package is synchronized with Fedora!

%global libmajor 0
%global girapi 1.0
%global girlib %mklibname %{name}-gir %{girapi}
%global libname %mklibname %{name} %{libmajor}
%global devname %mklibname %{name} -d

# Minimum dependent components
%global bubblewrap_version 0.8.0
%global ostree_version 2018.9

%{?!_pkgdocdir:%global _pkgdocdir %{_docdir}/%{name}}

Name:           flatpak
Version:        1.15.6
Release:        %mkrel 1
Summary:        Application deployment framework for desktop apps

Group:          System/Configuration/Packaging
License:        LGPLv2+
URL:            https://flatpak.org/
Source0:        https://github.com/flatpak/flatpak/releases/download/%{version}/%{name}-%{version}.tar.xz
Source1:        flatpak.sh

BuildRequires:  lib64appstream-devel
BuildRequires:  lib64appstream-glib-devel
BuildRequires:  pkgconfig(dconf)
BuildRequires:  pkgconfig(gdk-pixbuf-2.0)
BuildRequires:  pkgconfig(gio-unix-2.0)
BuildRequires:  pkgconfig(gobject-introspection-1.0) >= 1.40.0
BuildRequires:  pkgconfig(json-glib-1.0)
BuildRequires:  pkgconfig(libarchive) >= 2.8.0
BuildRequires:  pkgconfig(libseccomp)
BuildRequires:  pkgconfig(libsoup-2.4)
BuildRequires:  pkgconfig(libxml-2.0) >= 2.4
BuildRequires:  pkgconfig(polkit-gobject-1)
BuildRequires:  pkgconfig(xau)
BuildRequires:  lib64fuse-devel
BuildRequires:  lib64ostree-devel
BuildRequires:  bison
BuildRequires:  bubblewrap >= %{bubblewrap_version}
BuildRequires:  docbook-dtds
BuildRequires:  docbook-style-xsl
BuildRequires:  gettext
BuildRequires:  gpgme-devel
BuildRequires:  libcap-devel
BuildRequires:  xdg-dbus-proxy
BuildRequires:  xmlto
BuildRequires:  xsltproc
BuildRequires: python3-pyparsing
Requires:       fuse
Requires:       glib-networking
# Needed for confinement
Requires:       bubblewrap%{?_isa} >= %{bubblewrap_version}
Requires:       ostree%{?_isa} >= %{ostree_version}
Requires:       xdg-dbus-proxy%{?_isa}
Requires(pre):  shadow-utils

%description
flatpak is a system for building, distributing and running sandboxed desktop
applications on Linux. See https://wiki.gnome.org/Projects/SandboxedApps for
more information.

%package -n %{devname}
Summary:        Development files for %{name}
Group:          Development/Libraries
License:        LGPLv2+
Provides:       %{name}-devel = %{version}-%{release}
Provides:       %{name}-devel%{?_isa} = %{version}-%{release}
Requires:       %{name}%{?_isa} = %{version}-%{release}

%description -n %{devname}
This package contains the pkg-config file and development headers for %{name}.

%prep
%setup -q

%build
./autogen.sh
# Fix generic python shebangs.
find tests -name '*.py' -exec \
    sed -i -e 's|/usr/bin/python|/usr/bin/python3|' {} +

# Generate consistent IDs between runs to avoid multilib problems
export XMLTO_FLAGS="--stringparam generate.consistent.ids=1"
# User namespace support is sufficient.
 %configure2_5x \
                --with-priv-mode=none \
                --enable-docbook-docs \
                --with-system-bubblewrap \
                --with-system-dbus-proxy \
                --without-gtk-doc

%make_build V=1


%install
%make_install
install -pm 644 NEWS README.md %{buildroot}/%{_pkgdocdir}
# The system repo is not installed by the flatpak build system.
install -d %{buildroot}%{_localstatedir}/lib/flatpak
install -d %{buildroot}%{_sysconfdir}/flatpak/remotes.d
rm -f %{buildroot}%{_libdir}/libflatpak.la
rm -rf %{buildroot}/usr/lib/systemd
rm -rf %{buildroot}/usr/share/gtk-doc
rm -rf %{buildroot}/usr/lib/tmpfiles.d/flatpak.conf
#fix xfce manager settings
install -m 0644 %SOURCE1 %{buildroot}/%{_sysconfdir}/profile.d/flatpak.sh

%find_lang %{name}

%pre
rm -f %{_sysconfdir}/profile.d/flatpak.sh

getent group flatpak >/dev/null || groupadd -r flatpak
getent passwd flatpak >/dev/null || \
    useradd -r -g flatpak -d / -s /sbin/nologin \
     -c "User for flatpak system helper" flatpak
exit 0


%post
# Create an (empty) system-wide repo.
flatpak remote-list --system &> /dev/null || :


%files -f %{name}.lang
%doc %{_pkgdocdir}
%{_bindir}/flatpak
%{_bindir}/flatpak-bisect
%{_bindir}/flatpak-coredumpctl
%{_datadir}/bash-completion
%{_datadir}/dbus-1/interfaces/org.freedesktop.Flatpak.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.portal.Flatpak.xml
%{_datadir}/dbus-1/services/org.freedesktop.Flatpak.service
%{_datadir}/dbus-1/services/org.freedesktop.portal.Flatpak.service
%{_datadir}/dbus-1/system-services/org.freedesktop.Flatpak.SystemHelper.service
# Co-own directory.
%{_datadir}/%{name}
%{_datadir}/polkit-1/actions/org.freedesktop.Flatpak.policy
%{_datadir}/polkit-1/rules.d/org.freedesktop.Flatpak.rules
%{_datadir}/zsh/site-functions
%{_libexecdir}/flatpak-portal
%{_libexecdir}/flatpak-session-helper
%{_libexecdir}/flatpak-system-helper
%{_libexecdir}/flatpak-validate-icon
%{_libexecdir}/revokefs-fuse
%dir %{_localstatedir}/lib/flatpak
%{_mandir}/man1/%{name}*.1*
%{_mandir}/man5/%{name}-metadata.5*
%{_mandir}/man5/flatpak-flatpakref.5*
%{_mandir}/man5/flatpak-flatpakrepo.5*
%{_mandir}/man5/flatpak-installation.5*
%{_mandir}/man5/flatpak-remote.5*
%{_sysconfdir}/dbus-1/system.d/org.freedesktop.Flatpak.SystemHelper.conf
%{_sysconfdir}/flatpak/remotes.d
%{_sysconfdir}/profile.d/flatpak.sh
%{_libdir}/libflatpak.so.%{libmajor}
%{_libdir}/libflatpak.so.%{libmajor}.*
%{_libdir}/girepository-1.0/Flatpak-%{girapi}.typelib
%{_datadir}/dbus-1/interfaces/org.freedesktop.Flatpak.Authenticator.xml
/usr/lib/sysusers.d/flatpak.conf
/usr/libexec/flatpak-oci-authenticator
/usr/share/dbus-1/services/org.flatpak.Authenticator.Oci.service
/usr/share/fish/vendor_completions.d/flatpak.fish
/usr/share/fish/vendor_conf.d/flatpak.fish

%files -n %{devname}
%{_datadir}/gir-1.0/Flatpak-%{girapi}.gir
%{_includedir}/%{name}/
%{_libdir}/libflatpak.so
%{_libdir}/pkgconfig/%{name}.pc

%changelog
* Sun Dec 10 2023 tex - 1.15.6-1pclos2023
- new version

* Mon Mar 27 2023 tex - 1.15.4-1pclos2023
- new version

* Fri Nov 18 2022 tex - 1.15.1-1pclos2022
- new version

* Sat Oct 15 2022 tex - 1.14.0-2pclos2022
- rebuild against updates

* Sat Aug 27 2022 tex - 1.14.0-1pclos2022
- new version
